@@ -3,8 +3,10 @@
 import hashlib
 from sailthru_http import sailthru_http_request
 
-try: import simplejson as json
-except ImportError: import json
+try:
+    import simplejson as json
+except ImportError:
+    import json
 
 def extract_params(params):
     """
@@ -64,7 +66,7 @@ class SailthruClient(object):
         self.api_url = api_url if (api_url is not None) else 'https://api.sailthru.com'
         self.user_agent = 'Sailthru API Python Client'
 
-    def send(self, template, email, _vars=None, options=None, schedule_time=None):
+    def send(self, template, email, _vars=None, options=None, schedule_time=None, limit=None):
         """
         Remotely send an email template to a single email address.
         http://docs.sailthru.com/api/send
@@ -72,15 +74,18 @@ class SailthruClient(object):
         @param email: Email value
         @param _vars: a key/value hash of the replacement vars to use in the send. Each var may be referenced as {varname} within the template itself
         @param options: optional dictionary to include replyto and/or test keys
+        @param limit: optional dictionary to name, time, and handle conflicts of limits
         @param schedule_time: do not send the email immediately, but at some point in the future. Any date recognized by PHP's strtotime function is valid, but be sure to specify timezone or use a UTC time to avoid confusion
         """
         _vars = _vars or {}
         options = options or {}
+        limit = limit or {}
         data = {}
         data['template'] = template
         data['email'] = email
         data['vars'] = _vars
         data['options'] = options.copy()
+        data['limit'] = limit.copy()
         if schedule_time is not None:
             data['schedule_time'] = schedule_time
         return self.api_post('send', data)
@@ -320,8 +325,7 @@ class SailthruClient(object):
         """
         get metadata for all user templates
         """
-        data = {'template': ''}
-        return self.api_get('template', data)
+        return self.api_get('template', {})
 
     def delete_template(self, template_name):
         """
@@ -336,15 +340,13 @@ class SailthruClient(object):
         data['template'] = template
         return self.api_post('template', data)
 
-    def get_list(self, list, options=None):
+    def get_list(self, list_name, options=None):
         """
-        Download a list. Obviously, this can potentially be a very large download.
-        'txt' is default format since, its more compact as compare to others
-        http://docs.sailthru.com/api/list
+        Get detailed metadata information about a list.
         """
         options = options or {}
-        data = options.copy()
-        data['list'] = list
+        data = {'list': list_name}
+        data.update(options)
         return self.api_get('list', data)
 
     def get_lists(self):
@@ -522,21 +524,25 @@ class SailthruClient(object):
             return False
 
         sig = post_params['sig']
+        post_params = post_params.copy()
         del post_params['sig']
 
         if sig != get_signature_hash(post_params, self.secret):
             return False
 
         send_response = self.get_send(post_params['send_id'])
-        try:
-            send_response = send_response.get_body()
-            send_response = json.JSONEncoder().encode(send_response)
-            if not 'email' in send_response:
-                return False
-        except json.decoder.JSONDecodeError as json_err:
-            return False
 
-        if send_response['email'] != post_params['email']:
+        try:
+            send_body = send_response.get_body()
+            send_json = json.loads(send_body)
+            if not 'email' in send_body:
+                return False
+            if send_json['email'] != post_params['email']:
+                return False
+
+            send_body = json.JSONEncoder().encode(send_body)
+
+        except json.decoder.JSONDecodeError:
             return False
 
         return True
@@ -556,6 +562,7 @@ class SailthruClient(object):
             return False
 
         signature = post_params['sig']
+        post_params = post_params.copy()
         del post_params['sig']
 
         if signature != get_signature_hash(post_params, self.secret):
@@ -578,6 +585,7 @@ class SailthruClient(object):
             return False
 
         signature = post_params['sig']
+        post_params = post_params.copy()
         del post_params['sig']
 
         if signature != get_signature_hash(post_params, self.secret):
@@ -600,11 +608,11 @@ class SailthruClient(object):
             blast_id = post_params['blast_id']
             blast_response = self.get_blast(blast_id)
             try:
-                blast_response = send_response.get_body()
-                blast_response = json.JSONEncoder().encode(send_response)
+                blast_response = blast_response.get_body()
+                blast_response = json.JSONEncoder().encode(blast_response)
                 if 'error' in blast_response:
                     return False
-            except json.decoder.JSONDecodeError as json_err:
+            except json.decoder.JSONDecodeError:
                 return False
 
         return True
@@ -650,11 +658,10 @@ class SailthruClient(object):
         for param in binary_data_param:
             if param in data_keys:
                 binary_data[param] = open(data[param], 'r')
+                data = data.copy()
                 del data[param]
         json_payload = self._prepare_json_payload(data)
 
-        print data
-        
         return self._http_request(self.api_url+'/'+action, json_payload, "POST", binary_data)
 
     def api_delete(self, action, data):
@@ -670,7 +677,7 @@ class SailthruClient(object):
         Make Request to Sailthru API with given data and api key, format and signature hash
         """
         return self._http_request(self.api_url+'/'+action, self._prepare_json_payload(data), request_type)
-    
+
     def _http_request(self, url, data, method, file_data=None):
         file_data = file_data or {}
         return sailthru_http_request(url, data, method, file_data)
